==> scpdb-4.1.2.tgz: package/app/tasks/featured-daily-rotation.ts <==
'use strict';

import {log, logToDiscord} from '../core/utils';
import {
    getListCards,
    updateCardList,
    DAILY_BACKLOG_LIST_ID,
    DAILY_PREVIOUS_LIST_ID
} from '../components/trello';
import {WikidotPage} from '../models';
import {wk, WKPage} from '../components/wikidot-kit';

const PAGE_NAME_REG = /^[a-zA-Z0-9_:-]+$/;
const FEATURED_BLOCK_REGEXP = /\[!--\sFEATURED_DAILY_START\s--][\s\S]*\[!--\sFEATURED_DAILY_END\s--]/;
const WIKI_NAME = 'scp-ru';
const PAGE_NAME = '_default:main';

module.exports = async function run(): Promise<any> {
    const previousCards = (await getListCards(DAILY_PREVIOUS_LIST_ID)).slice(0, 3);
    const backlogCards = await getListCards(DAILY_BACKLOG_LIST_ID);
    const current = backlogCards[0];

    if (!current) {
        throw new Error('Featured Daily Queue is empty');
    }

    const name = current.name;
    if (!PAGE_NAME_REG.test(name)) {
        throw new Error(`Featured Daily page name is not valid ("${name}")`);
    }

    log(`Rotating featured daily page to ${name}`);

    const currentPage = await WikidotPage.query().where({wikiName: WIKI_NAME, name}).first();
    const previousPages = await Promise.all(previousCards.map(async ({name: cardName}) =>
        WikidotPage.query().where({wikiName: WIKI_NAME, name: cardName}).first()));

    const previousPagesLinks = previousPages.map(page =>
        `- [/${page.name} ${page.title}]`).join('\n');

    const updatedBlock = `
[!-- FEATURED_DAILY_START --]
[[div class="scp-featured__block scp-featured__block_type_daily"]]
  [[div class="scp-featured__title"]]
    Объект дня
  [[/div]]
  [[div class="scp-featured__page-title"]]
    [/${currentPage.name} ${currentPage.title}]
  [[/div]]
  [[div class="scp-featured__content"]]
  [[/div]]

  [[div class="scp-featured__previous"]]
    [[span class="scp-featured__previous-title"]]Предыдущие дни:[[/span]]
      ${previousPagesLinks}
  [[/div]]
[[/div]]
[!-- FEATURED_DAILY_END --]
    `.trim();

    const content = (await wk.call(WIKI_NAME, 'pages.get_one', {page: PAGE_NAME}) as WKPage).content;
    const updatedContent = content.replace(FEATURED_BLOCK_REGEXP, updatedBlock);

    await wk.call(WIKI_NAME, 'pages.save_one', {
        page: PAGE_NAME,
        content: updatedContent
    });

    await updateCardList(current.id, DAILY_PREVIOUS_LIST_ID, (previousCards[0] && previousCards[0].pos - 1));

    logToDiscord(`Successfully rotated featured daily page to ${name}`);
};

==> scpdb-4.5.0.tgz: package/app/tasks/featured-daily-rotation.ts <==
'use strict';

import {log, logToDiscord} from '../core/utils';
import {
    getListCards,
    updateCardList,
    DAILY_BACKLOG_LIST_ID,
    DAILY_PREVIOUS_LIST_ID
} from '../components/trello';
import {WikidotPage} from '../models';
import {wk, WKPage} from '../components/wikidot-kit';

const PAGE_NAME_REG = /^[a-zA-Z0-9_:-]+$/;
const FEATURED_BLOCK_REGEXP = /\[!--\sFEATURED_DAILY_START\s--][\s\S]*\[!--\sFEATURED_DAILY_END\s--]/;
const WIKI_NAME = 'scp-ru';
const PAGE_NAME = '_default:main';

export default async function run(): Promise<any> {
    const previousCards = (await getListCards(DAILY_PREVIOUS_LIST_ID)).slice(0, 3);
    const backlogCards = await getListCards(DAILY_BACKLOG_LIST_ID);
    const current = backlogCards[0];

    if (!current) {
        throw new Error('Featured Daily Queue is empty');
    }

    const name = current.name;
    if (!PAGE_NAME_REG.test(name)) {
        throw new Error(`Featured Daily page name is not valid ("${name}")`);
    }

    log(`Rotating featured daily page to ${name}`);

    const currentPage = await WikidotPage.query().where({wikiName: WIKI_NAME, name}).first();
    const previousPages = await Promise.all(previousCards.map(async ({name: cardName}) =>
        WikidotPage.query().where({wikiName: WIKI_NAME, name: cardName}).first()));

    const previousPagesLinks = previousPages.map(page =>
        `- [/${page.name} ${page.title}]`).join('\n');

    const updatedBlock = `
[!-- FEATURED_DAILY_START --]
[[div class="scp-featured__block scp-featured__block_type_daily"]]
  [[div class="scp-featured__title"]]
    Объект дня
  [[/div]]
  [[div class="scp-featured__page-title"]]
    [/${currentPage.name} ${currentPage.title}]
  [[/div]]
  [[div class="scp-featured__content"]]
  [[/div]]

  [[div class="scp-featured__previous"]]
    [[span class="scp-featured__previous-title"]]Предыдущие дни:[[/span]]
      ${previousPagesLinks}
  [[/div]]
[[/div]]
[!-- FEATURED_DAILY_END --]
    `.trim();

    const content = (await wk.call(WIKI_NAME, 'pages.get_one', {page: PAGE_NAME}) as WKPage).content;
    const updatedContent = content.replace(FEATURED_BLOCK_REGEXP, updatedBlock);

    await wk.call(WIKI_NAME, 'pages.save_one', {
        page: PAGE_NAME,
        content: updatedContent
    });

    await updateCardList(current.id, DAILY_PREVIOUS_LIST_ID, (previousCards[0] && previousCards[0].pos - 1));

    logToDiscord(`Successfully rotated featured daily page to ${name}`);
}
